import type { SpareTypeTree, SpareTypeVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  root = '/eims/spareType',
  spareTypeExport = '/eims/spareType/export',
  spareTypeList = '/eims/spareType/list',
  spareTypeTree = '/eims/spareType/tree'
}

/**
 * 查询备件类型列表
 * @param query
 * @returns {*}
 */

export function listSpareType(params?: any) {
  return requestClient.get<SpareTypeVO[]>(Api.spareTypeList, { params });
}

/**
 * 获取备件类型树
 * @returns 部门树数组
 */
export function getSpareTypeTree() {
  return requestClient.get<SpareTypeTree[]>(Api.spareTypeTree);
}

/**
 * 查询备件类型详细
 * @param spareTypeId
 */
export function getSpareType(spareTypeId: ID) {
  return requestClient.get<SpareTypeVO>(`${Api.root}/${spareTypeId}`);
}

/**
 * 新增备件类型
 * @param data
 */
export function addSpareType(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}
/**
 * 修改备件类型
 * @param data
 */
export function updateSpareType(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除备件类型
 * @param spareTypeId
 */
export function delSpareType(spareTypeId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${spareTypeId}`);
}
/**
 * 导出
 * @param
 */
export function spareTypeExport(data: any) {
  return commonExport(Api.spareTypeExport, data);
}
